==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-mount/mount_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>デバイス &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; は接続されました</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="53"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>デバイス &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; は接続解除されました</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation>リムーバルメディア/デバイスの管理</translation>
    </message>
</context>
<context>
    <name>LXQtMountConfiguration</name>
    <message>
        <location filename="../../../lxqtmountconfiguration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>リムーバブルメディアの設定</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>挙動</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>デバイスが接続されたとき</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.cpp" line="44"/>
        <source>Popup menu</source>
        <translation>メニューをポップアップ</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.cpp" line="45"/>
        <source>Show info</source>
        <translation>情報を表示</translation>
    </message>
    <message>
        <location filename="../../../lxqtmountconfiguration.cpp" line="46"/>
        <source>Do nothing</source>
        <translation>何もしない</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../../../menudiskitem.cpp" line="120"/>
        <location filename="../../../menudiskitem.cpp" line="155"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">リムーバルメディア/デバイスの管理</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="121"/>
        <source>Mounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="156"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../../../mountbutton.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>リムーバルメディア/デバイスの管理</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../../../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>接続可能なデバイスはありません</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-mount/mount_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Button</name>
    <message>
        <location filename="../../../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">リムーバルメディア/デバイスの管理</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../../../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation type="unfinished">リムーバブルメディアの設定</translation>
    </message>
    <message>
        <location filename="../../../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation type="unfinished">挙動</translation>
    </message>
    <message>
        <location filename="../../../configuration.ui" line="26"/>
        <source>When a device is connected :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="40"/>
        <source>Popup menu</source>
        <translation type="unfinished">メニューをポップアップ</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="41"/>
        <source>Show info</source>
        <translation type="unfinished">情報を表示</translation>
    </message>
    <message>
        <location filename="../../../configuration.cpp" line="42"/>
        <source>Do nothing</source>
        <translation type="unfinished">何もしない</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>デバイス &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; は接続されました</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>デバイス &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; は接続解除されました</translation>
    </message>
    <message>
        <location filename="../../../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>リムーバルメディア/デバイスの管理</translation>
    </message>
</context>
<context>
    <name>LXQtMountConfiguration</name>
    <message>
        <source>Removable Media Settings</source>
        <translation type="vanished">リムーバブルメディアの設定</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation type="vanished">挙動</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation type="vanished">デバイスが接続されたとき</translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation type="vanished">メニューをポップアップ</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation type="vanished">情報を表示</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation type="vanished">何もしない</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../../../menudiskitem.cpp" line="155"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="157"/>
        <location filename="../../../menudiskitem.cpp" line="178"/>
        <source>Removable media/devices manager</source>
        <translation type="unfinished">リムーバルメディア/デバイスの管理</translation>
    </message>
    <message>
        <location filename="../../../menudiskitem.cpp" line="176"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation type="vanished">リムーバルメディア/デバイスの管理</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../../../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>接続可能なデバイスはありません</translation>
    </message>
</context>
</TS>
